@@ -23,16 +23,21 @@
  *
  */
 
-#include <stdio.h>
-#include <unistd.h>
-#include <stdlib.h>
+#include "wmnut-common.h"	/* includes config.h */
 #include "wmgeneral.h"
-#include "config.h"
 
 #ifdef HAVE_GETOPT_LONG
 # include <getopt.h>
 #endif
 
+#if (defined HAVE_REALPATH) && HAVE_REALPATH
+# ifdef HAVE_LIMITS_H
+#  include <limits.h>
+# endif
+# ifdef HAVE_STDLIB_H
+#  include <stdlib.h>
+# endif
+#endif
 
 /*******************************************************************************\
 |* AddRcKey                                                                     |
@@ -40,8 +45,11 @@
 void AddRcKey(rckeys *key, const char *label, int type, void *var) {
 
 	if (label != NULL) {
-/*		key->label = (char *)xmalloc(strlen(label) + 1); */
+#if (defined HAVE_XMALLOC) && HAVE_XMALLOC
+		key->label = (char *)xmalloc(strlen(label) + 1);
+#else
 		key->label = (char *)malloc(strlen(label) + 1);
+#endif	/* HAVE_XMALLOC */
 		strcpy(key->label, label);
 	}
 	else
@@ -65,7 +73,39 @@ void AddRcKey(rckeys *key, const char *label, int type, void *var) {
 	}
 }
 
-/* TODO : void FreeRcKeys(rckeys *key)*/
+/*******************************************************************************\
+|* FreeRcKeyData                                                                |
+\*******************************************************************************/
+void FreeRcKeyData(rckeys *key) {
+	if (!key)
+		return;
+
+	if (key->label) {
+		free(key->label);
+		key->label = NULL;
+	}
+
+	if (key->type == TYPE_STRING && key->var.str) {
+		free(key->var.str);
+		key->var.str = NULL;
+	}
+}
+
+/*******************************************************************************\
+|* FreeRcKeys                                                                   |
+\*******************************************************************************/
+void FreeRcKeys(rckeys *keys) {
+	/* NOTE: Assumes it accepts an array to free() its elements;
+	 * if this array itself is dynamic, caller should free() it */
+	int	keynum;
+
+	if (!keys)
+		return;
+
+	for (keynum = 0; keys[keynum].type != TYPE_NULL; keynum++) {
+		FreeRcKeyData(&keys[keynum]);
+	}
+}
 
 /*******************************************************************************\
 |* ParseRCFile                                                                  |
@@ -83,7 +123,7 @@ void ParseRCFile(const char *filename, rckeys *keys)
 #ifdef DEBUG
 		printf("Opening rc file %s\n", filename);
 #endif
-		while (fgets(temp, 128, fp)) {
+		while (fgets(temp, sizeof(temp), fp)) {
 			if (temp[0] != '#') {
 				key = 0;
 				while (key >= 0 && keys[key].label) {
@@ -102,12 +142,12 @@ void ParseRCFile(const char *filename, rckeys *keys)
 						switch(keys[key].type)
 						{
 							case TYPE_STRING:
-								/*
-								if (keys[key].var.str !=NULL)
+#if (defined HAVE_XMALLOC) && HAVE_XMALLOC
+								if (keys[key].var.str != NULL)
 									free(keys[key].var.str);
 								keys[key].var.str = (char *)xmalloc(strlen(p) + 1);
 								strncpy(keys[key].var.str, p, strlen(p));
-								*/
+#endif	/* HAVE_XMALLOC */
 								if (!strcmp(keys[key].label, "UPS"))
 									AddHost(p);
 								break;
@@ -136,7 +176,7 @@ void ParseRCFile(const char *filename, rckeys *keys)
 \*******************************************************************************/
 void LoadRCFile(rckeys *keys)
 {
-	char	home_file[128];
+	char	home_file[NUT_PATH_MAX];
 	char	*p;
 
 #ifdef DEBUG
@@ -146,8 +186,28 @@ void LoadRCFile(rckeys *keys)
 	ParseRCFile(MAINRC_FILE, keys);
 
 	p = getenv("HOME");
-	sprintf(home_file, "%s/%s", p, RC_FILE);
-	ParseRCFile(home_file, keys);
+	home_file[0] = '\0';
+	if (p) {
+#if (defined HAVE_REALPATH) && HAVE_REALPATH
+		char	resolved_path[NUT_PATH_MAX];
+		if (realpath(p, resolved_path)) {
+			p = resolved_path;
+		} else {
+			fprintf(stderr, "Invalid or unsafe HOME directory: %s\n", p);
+			p = NULL;
+		}
+
+		if (p)
+#endif
+		/* Sanity-check that HOME dir is absolute, does not have
+		 * any escape chars and/or dot-dot upstaging */
+		if (p[0] == '/' && (strcmp(p, "/../") || strcmp(p, "\\"))) {
+			snprintf(home_file, sizeof(home_file), "%s/%s", p, RC_FILE);
+			ParseRCFile(home_file, keys);
+		} else {
+			fprintf(stderr, "Invalid or unsafe HOME directory: %s\n", p);
+		}
+	}
 }
 
 /*******************************************************************************\
