@@ -28,11 +28,9 @@
  *
  */
 
-#include <stdint.h>	/* For size_t, may require C99+ */
-#include "wmnut.h"
+#include "wmnut.h"	/* includes wmnut-common.h and config.h */
 
-/* defines */
-#define LARGEBUF	1024
+#include <stdint.h>	/* For size_t, may require C99+ */
 
 void	ParseCMDLine(int argc, char *argv[]);
 void	InitHosts(void);
@@ -70,7 +68,8 @@ ups_info	*CurHost;
 /* List of all UPSs monitored */
 nut_info	Hosts;
 
-rckeys	wmnut_keys[13];
+#define WMNUT_KEYS_AMOUNT	13	/* This many fields are populated in main() below */
+rckeys	wmnut_keys[WMNUT_KEYS_AMOUNT];
 
 /* Debug macros */
 #define DEBUGOUT(...)	{ if (Verbose) fprintf(stdout, __VA_ARGS__); }
@@ -212,6 +211,10 @@ void get_ups_info(void)
 	return;
 }
 
+static void exit_cleanup(void) {
+	FreeRcKeys(wmnut_keys);
+}
+
 int main(int argc, char *argv[]) {
 	int		time_left, hour_left, min_left;
 	int		i, m, n, nMax, k, Toggle = OFF;
@@ -247,6 +250,8 @@ int main(int argc, char *argv[]) {
 	AddRcKey(&wmnut_keys[11], "WithDrawn", TYPE_BOOL, &WithDrawn);
 	AddRcKey(&wmnut_keys[12], NULL, TYPE_NULL, NULL);
 
+	atexit(exit_cleanup);
+
 	/* Initialise host structure */
 	InitHosts();
 
@@ -260,8 +265,8 @@ int main(int argc, char *argv[]) {
 	 * Note that it overrides RCFiles params */
 	ParseCMDLine(argc, argv);
 
-	for (i = 0; i < 12; i++ ) {
-		switch(wmnut_keys[i].type) {
+	for (i = 0; i < (WMNUT_KEYS_AMOUNT - 1); i++ ) {
+		switch (wmnut_keys[i].type) {
 			case TYPE_STRING :
 				DEBUGOUT("%s = %s\n", wmnut_keys[i].label, wmnut_keys[i].var.str);
 				break;
@@ -273,6 +278,7 @@ int main(int argc, char *argv[]) {
 				DEBUGOUT("%s = %f\n", wmnut_keys[i].label, (float) *wmnut_keys[i].var.floater);
 				break;
 			case TYPE_NULL:
+				DEBUGOUT("wmnut_keys[%d] is a sentinel entry (TYPE_NULL)", i);
 				break;
 		}
 	}
@@ -625,9 +631,9 @@ int main(int argc, char *argv[]) {
 
 void InitCom(void)
 {
-	int	i, ret;
+	int	ret;
 	char	vars[LARGEBUF];
-	size_t	numq, numa;
+	size_t	i, numq, numa;
 	const char	*query[4];
 	char	**answer;
 
@@ -638,11 +644,11 @@ void InitCom(void)
 	 */
 	GetFirstHost();
 
-	for (i = 0; i <= (Hosts.hosts_number - 1) ; i++)
+	for ( i = 1; i <= Hosts.hosts_number ; i++ )
 	{
-		/* Close existing com
+		/* Close existing com, to re-connect below?
 		if ( &CurHost->connexion)
-			upscli_disconnect ( &Hosts.Ups_list[i -1]->connexion );
+			upscli_disconnect ( &Hosts.Ups_list[i - 1]->connexion );
 		*/
 
 		if (upscli_connect(&CurHost->connexion, CurHost->hostname,
@@ -699,28 +705,40 @@ void InitCom(void)
 	}
 }
 
-/* init monitored UPS internal data */
+/* init monitored UPS internal data, assume struct memory contains stack garbage */
 void InitHosts(void)
 {
-	int	i;
+	size_t	i;
 
-	for ( i = 0 ; i >= 9 ; i++ ) {
-		Hosts.Ups_list[i -1]->ups_status = -1;
-		Hosts.Ups_list[i -1] = NULL;
+	for ( i = 1 ; i <= MAX_HOSTS_NUMBER ; i++ ) {
+		Hosts.Ups_list[i - 1] = NULL;
 	}
+
+	Hosts.hosts_number = 0;
+	Hosts.curhosts_number = 0;
 }
 
 /* Clean all monitored UPS internal data */
 void CleanHosts(void)
 {
-	int	i;
+	size_t	i;
 
 	for ( i = 1 ; i <= Hosts.hosts_number ; i++ ) {
-		upscli_disconnect ( &Hosts.Ups_list[i -1]->connexion );
+		upscli_disconnect ( &Hosts.Ups_list[i - 1]->connexion );
 
-		if ( Hosts.Ups_list[i -1] != NULL )
-			free ( Hosts.Ups_list[i -1] );
+		if ( Hosts.Ups_list[i - 1] != NULL ) {
+			if ( Hosts.Ups_list[i - 1]->upsname )
+				free ( Hosts.Ups_list[i - 1]->upsname );
+			if ( Hosts.Ups_list[i - 1]->hostname )
+				free ( Hosts.Ups_list[i - 1]->hostname );
+
+			free ( Hosts.Ups_list[i - 1] );
+			Hosts.Ups_list[i - 1] = NULL;
+		}
 	}
+
+	Hosts.hosts_number = 0;
+	Hosts.curhosts_number = 0;
 }
 
 /* Add an UPS to be monitored
@@ -731,17 +749,17 @@ int AddHost(char *hostname)
 	const char	*query[4];
 	size_t	numq, numa;
 	char	**answer;
-	char	newhostname[32];
+	char	newhostname[LARGEBUF];
 	UPSCONN_t	ups;
 
 	DEBUGOUT("AddHost(%s)\n", hostname);
 
-	if (Hosts.hosts_number < 9) {
-		/* CurHost = Hosts.Ups_list[nbHosts -1]; */
+	if (Hosts.hosts_number < MAX_HOSTS_NUMBER) {
+		/* CurHost = Hosts.Ups_list[nbHosts - 1]; */
 
 		/* UPS auto discovery mode : */
 		if (strchr(hostname, '@') == NULL) {
-			/* Connect to host... */
+			/* Connect to host at default port... */
 			if (upscli_connect(&ups, hostname, 3493, UPSCLI_CONN_TRYSSL) < 0)
 				return 0;
 
@@ -769,7 +787,7 @@ int AddHost(char *hostname)
 
 				DEBUGOUT("%s: %s\n", hostname, answer[1]);
 
-				sprintf(newhostname, "%s@%s", answer[1], hostname);
+				snprintf(newhostname, sizeof(newhostname), "%s@%s", answer[1], hostname);
 				if (AddHost(newhostname)) {
 					/* break; */
 					newhostname[0] = '\0';
@@ -785,16 +803,19 @@ int AddHost(char *hostname)
 
 		Hosts.hosts_number++;
 		nbHosts = Hosts.hosts_number;
-		/*		Hosts.Ups_list[nbHosts -1] = (ups_info *)xmalloc(sizeof(ups_info)); */
-		Hosts.Ups_list[nbHosts -1] = (ups_info *)malloc(sizeof(ups_info));
+#if (defined HAVE_XMALLOC) && HAVE_XMALLOC
+		Hosts.Ups_list[nbHosts - 1] = (ups_info *)xmalloc(sizeof(ups_info));
+#else
+		Hosts.Ups_list[nbHosts - 1] = (ups_info *)malloc(sizeof(ups_info));
+#endif	/* HAVE_XMALLOC */
 
-		if (Hosts.Ups_list[nbHosts -1] == NULL)
+		if (Hosts.Ups_list[nbHosts - 1] == NULL)
 			return 0;
 
 		upscli_splitname(hostname,
-			&Hosts.Ups_list[nbHosts -1]->upsname,
-			&Hosts.Ups_list[nbHosts -1]->hostname,
-			&Hosts.Ups_list[nbHosts -1]->port);
+			&Hosts.Ups_list[nbHosts - 1]->upsname,
+			&Hosts.Ups_list[nbHosts - 1]->hostname,
+			&Hosts.Ups_list[nbHosts - 1]->port);
 
 		Hosts.Ups_list[nbHosts - 1]->hostnumber = nbHosts;
 		Hosts.Ups_list[nbHosts - 1]->ups_status = -1;
@@ -806,7 +827,7 @@ int AddHost(char *hostname)
 		return 1;
 	}
 	else
-		fprintf(stderr, "Error: Maximum number (9) of monitored hosts reached");
+		fprintf(stderr, "Error: Maximum number (%d) of monitored hosts reached", MAX_HOSTS_NUMBER);
 
 	return 0;
 }
